<?php
/***********************************************************
*  Module       : General
*  Language     : ES Spanish
*  Version      : vt5.2.0
*  Created Date : 2008-01-18 17:46:07 Last change : 2008-01-18 18:11:37
*  Author       : JPL TSolucio, S.L.  -  rasomu
*  License      : 

***********************************************************/

$app_strings = array (
      'LBL_BROWSER_TITLE' => 'vtiger CRM 5 - CRM Comercial de Código Abierto',
      'LBL_MY_ACCOUNT' => 'Mi Cuenta',
      'LBL_MY_PREFERENCES' => 'Mis Preferencias',
      'LBL_ADMIN' => 'Admin',
      'LBL_LOGOUT' => 'Salir',
      'LBL_SEARCH' => 'Buscar',
      'LBL_LAST_VIEWED' => 'Recientes',
      'LBL_TODAY' => 'Hoy',
      'LBL_ALL' => 'Todas',
      'LBL_SHOW' => 'Mostrar :',
      'today' => 'Hoy -',
      'all' => 'Todos',
      'LBL_UPCOMING_EVENTS' => 'Eventos Programados',
      'LBL_PENDING_EVENTS' => 'Eventos Pendientes',
      'NTC_WELCOME_MESSAGE' => '¡Bienvenido a vtiger CRM!',
      'NTC_DESCRIPTION' => 'Utilice un nombre de usuario y una contraseña válidas para entrar a vtiger CRM.',
      'NTC_WELCOME' => 'Bienvenido',
      'NTC_NO_ITEMS_DISPLAY' => 'Sin elementos',
      'LBL_OR' => 'o',
      'LBL_ALT_HOT_KEY' => 'Alt+',
      'LBL_SAVE_LABEL' => 'Guardar',
      'LBL_REPLACE_LABEL' => 'Sustituir',
      'LBL_APPLY_BUTTON_LABEL' => 'Aplicar',
      'LBL_SEND_MAIL_BUTTON' => 'Enviar un Email',
      'LBL_SAVE_BUTTON_TITLE' => 'Guardar [Alt+S]',
      'LBL_EDIT_BUTTON_TITLE' => 'Editar [Alt+E]',
      'LBL_CONVERTSO_BUTTON_TITLE' => 'Crear Pedido',
      'LBL_CONVERTINVOICE_BUTTON_TITLE' => 'Crear Factura',
      'LBL_EDIT_BUTTON' => 'Editar',
      'LBL_DUPLICATE_BUTTON_TITLE' => 'Duplicar [Alt+U]',
      'LBL_DUPLICATE_BUTTON' => 'Duplicar',
      'LBL_TABCUSTOMISE_BUTTON_TITLE' => 'Personalizar [Alt+C]',
      'LBL_FORUM_HIDE_BUTTON_TITLE' => 'Ocultar Foros [Alt+I]',
      'LBL_FORUM_HIDE_BUTTON_KEY' => 'H',
      'LBL_FORUM_SHOW_BUTTON_TITLE' => 'Mostrar Foros [Alt+W]',
      'LBL_FORUM_SHOW_BUTTON_KEY' => 'W',
      'LBL_TABCUSTOMISE_BUTTON' => 'Personalizar',
      'LBL_DELETE_BUTTON_TITLE' => 'Borrar [Alt+D]',
      'LBL_DELETE_BUTTON' => 'Borrar',
      'LBL_FIND_BUTTON' => 'Buscar',
      'LBL_CONVERT_BUTTON_TITLE' => 'Convertir [Alt+C]',
      'LBL_CONVERT_BUTTON_KEY' => 'C',
      'LBL_CONVERT_BUTTON_LABEL' => 'Convertir Pre-Contacto',
      'LBL_TABCUSTOMISE_BUTTON_KEY' => 'C',
      'LBL_TABCUSTOMISE_BUTTON_LABEL' => 'Personalizar Pestañas',
      'LBL_ROLES_BUTTON_LABEL' => 'Mostrar Roles',
      'LBL_LISTROLES_BUTTON_LABEL' => 'Listar Roles',
      'LBL_FORUM_HIDE_BUTTON_LABEL' => 'Ocultar Foros',
      'LBL_FORUM_SHOW_BUTTON_LABEL' => 'Mostrar Foros',
      'LBL_NEW_BUTTON_TITLE' => 'Nuevo [Alt+N]',
      'LBL_CHANGE_BUTTON_TITLE' => 'Seleccionar [Alt+G]',
      'LBL_CANCEL_BUTTON_TITLE' => 'Cancelar [Alt+X]',
      'LBL_SEARCH_BUTTON_TITLE' => 'Buscar [Alt+Q]',
      'LBL_CLEAR_BUTTON_TITLE' => 'Limpiar [Alt+C]',
      'LBL_SELECT_BUTTON_TITLE' => 'Seleccionar [Alt+T]',
      'LBL_CREATE_BUTTON_LABEL' => 'Crear',
      'LBL_GENERATE' => 'Generar',
      'LBL_SAVE_BUTTON_KEY' => 'S',
      'LBL_EDIT_BUTTON_KEY' => 'E',
      'LBL_CONVERTSO_BUTTON_KEY' => 'S',
      'LBL_CONVERTINVOICE_BUTTON_KEY' => 'I',
      'LBL_DUPLICATE_BUTTON_KEY' => 'U',
      'LBL_DELETE_BUTTON_KEY' => 'D',
      'LBL_NEW_BUTTON_KEY' => 'N',
      'LBL_CHANGE_BUTTON_KEY' => 'G',
      'LBL_CANCEL_BUTTON_KEY' => 'X',
      'LBL_SEARCH_BUTTON_KEY' => 'Q',
      'LBL_CLEAR_BUTTON_KEY' => 'C',
      'LBL_SELECT_BUTTON_KEY' => 'T',
      'LBL_SAVE_BUTTON_LABEL' => 'Guardar',
      'LBL_EDIT_BUTTON_LABEL' => 'Editar',
      'LBL_CONVERTSO_BUTTON_LABEL' => 'Crear Pedido',
      'LBL_CONVERTINVOICE_BUTTON_LABEL' => 'Crear Factura',
      'LBL_DUPLICATE_BUTTON_LABEL' => 'Duplicar',
      'LBL_DELETE_BUTTON_LABEL' => 'Borrar',
      'LBL_NEW_BUTTON_LABEL' => 'Nuevo',
      'LBL_CHANGE_BUTTON_LABEL' => 'Seleccionar',
      'LBL_CANCEL_BUTTON_LABEL' => 'Cancelar',
      'LBL_SEARCH_BUTTON_LABEL' => 'Buscar',
      'LBL_CLEAR_BUTTON_LABEL' => 'Limpiar',
      'LBL_SELECT_BUTTON_LABEL' => 'Seleccionar',
      'LBL_SELECT_CONTACT_BUTTON_TITLE' => 'Seleccionar Usuario [Alt+T]',
      'LBL_SELECT_CONTACT_BUTTON_KEY' => 'T',
      'LBL_SELECT_CONTACT_BUTTON_LABEL' => 'Seleccionar Contacto',
      'LBL_SELECT_CAMPAIGN_BUTTON_LABEL' => 'Seleccionar Campaña',
      'LBL_SELECT_USER_BUTTON_TITLE' => 'Seleccionar Usuario [Alt+U]',
      'LBL_SELECT_USER_BUTTON_KEY' => 'U',
      'LBL_SELECT_USER_BUTTON_LABEL' => 'Seleccionar Usuario',
      'LBL_SETTINGS' => 'Configuración',
      'LBL_LIST_USERIP' => 'IP Usuario',
      'LBL_LIST_SIGNIN' => 'Hora de Entrada',
      'LBL_LIST_SIGNOUT' => 'Hora de Salida',
      'LBL_LIST_STATUS' => 'Estado',
      'LBL_LIST_NAME' => 'Nombre',
      'LBL_LIST_USER_NAME' => 'Nombre del Usuario',
      'LBL_LIST_EMAIL' => 'Email',
      'LBL_LIST_PHONE' => 'Teléfono',
      'LBL_LIST_CONTACT_NAME' => 'Contacto',
      'LBL_LIST_ACCOUNT_NAME' => 'Cuenta',
      'LBL_USER_LIST' => 'Lista de Usuarios',
      'LBL_CONTACT_LIST' => 'Lista de Contactos',
      'LBL_LNK_SETTINGS' => 'Configuración',
      'LNK_IMPORT_LEADS' => 'Importar Pre-Contacto',
      'LBL_LOCATE_MAP' => 'Situar en Mapa',
      'LBL_ADDRESS' => 'Dirección',
      'LBL_ADD_TAG' => 'Añadir Marcador',
      'LBL_TAG_IT' => 'Marcarlo',
      'LBL_CLOSE' => 'Cerrar',
      'LNK_ADVANCED_SEARCH' => 'Avanzada',
      'LNK_BASIC_SEARCH' => 'Básica',
      'LNK_EDIT' => 'editar',
      'LNK_REMOVE' => 'eliminar',
      'LNK_DELETE' => 'borrar',
      'LNK_LIST_START' => 'Inicio',
      'LNK_LIST_NEXT' => 'Siguiente',
      'LNK_LIST_PREVIOUS' => 'Atras',
      'LNK_LIST_END' => 'Fin',
      'LBL_LIST_OF' => 'de',
      'LNK_PRINT' => 'Imprimir',
      'LNK_HELP' => 'Ayuda',
      'LNK_VTDOCS' => 'Documentación de vtiger',
      'LNK_ABOUT' => 'Acerca de...',
      'LNK_OUTLOOK' => './include/images/outlook_download.gif',
      'SINGLE_Accounts' => 'Cuenta',
      'SINGLE_Contacts' => 'Contacto',
      'SINGLE_Campaigns' => 'Campaña',
      'SINGLE_HelpDesk' => 'Ticket',
      'SINGLE_Leads' => 'Pre-Contacto',
      'SINGLE_Events' => 'Evento',
      'SINGLE_Calendar' => 'Tarea',
      'SINGLE_Dashboard' => 'Análisis',
      'SINGLE_Emails' => 'Email',
      'SINGLE_Faq' => 'Faq',
      'SINGLE_Home' => 'Portada',
      'SINGLE_Invoice' => 'Factura',
      'SINGLE_Potentials' => 'Potencial',
      'SINGLE_Products' => 'Producto',
      'SINGLE_Vendors' => 'Proveedor',
      'SINGLE_PriceBooks' => 'Tarifa',
      'SINGLE_Quotes' => 'Presupuesto',
      'SINGLE_PurchaseOrder' => 'Orden de Compra',
      'SINGLE_SalesOrder' => 'Pedido',
      'SINGLE_Rss' => 'Rss',
      'SINGLE_Reports' => 'Informe',
      'SINGLE_Portal' => 'Portal',
      'SINGLE_Webmails' => 'Webmail',
      'SINGLE_Users' => 'Usuario',
      'ServiceContracts' => 'Contratos de Servicio',
      'Service Contracts' => 'Contratos de Servicio',
      'SINGLE_ServiceContracts' => 'Contrato de Servicio',
      'Services'=>'Servicios',
      'SINGLE_Services'=>'Servicio',
      'Parent Product' => 'Producto Paterno',
      'NEW' => 'Nuevo',
      'NTC_REQUIRED' => 'Campo obligatorio',
      'LBL_REQUIRED_SYMBOL' => '*',
      'LBL_CURRENCY_SYMBOL' => '$',
      'LBL_THOUSANDS_SYMBOL' => 'K',
      'NTC_DATE_FORMAT' => '(aaaa-mm-dd)',
      'NTC_TIME_FORMAT' => '(24:00)',
      'NTC_DATE_TIME_FORMAT' => '(aaaa-mm-dd 24:00)',
      'NTC_DELETE_CONFIRMATION' => '¿Está seguro que desea eliminar este expediente?',
      'NTC_ACCOUNT_DELETE_CONFIRMATION' => 'Borrar esta cuenta eliminará sus relaciones con Potenciales, Presupuestos, Pedidos y Facturas. ¿Quiere Borrar la Cuenta?',
      'NTC_VENDOR_DELETE_CONFIRMATION' => 'Borrar este proveedor eliminará sus relaciones con Potenciales, Presupuestos, Pedidos y Facturas. ¿Quiere Borrar el Proveedor?',
      'ERR_DELETE_RECORD' => ' Debe especificar un registro para poder eliminar el contacto.',
      'ERR_CREATING_TABLE' => 'Error al crear la tabla: ',
      'ERR_CREATING_FIELDS' => 'Error al completar detalles adicionales de campo: ',
      'ERR_MISSING_REQUIRED_FIELDS' => 'Faltan campos requeridos:',
      'ERR_INVALID_EMAIL_ADDRESS' => 'Dirección de Email no válida.',
      'ERR_INVALID_SECONDARY_EMAIL_ADDRESS' => 'no es una dirección de email alternativa válida',
      'ERR_INVALID_DATE_FORMAT' => 'El formato de la fecha debe ser: aaaa-mm-dd',
      'ERR_INVALID_MONTH' => ' Por favor, introduzca un mes válido.',
      'ERR_INVALID_DAY' => 'Por favor, introduzca un dia válido.',
      'ERR_INVALID_YEAR' => 'Por favor, introduzca un año de 4 dígitos.',
      'ERR_INVALID_DATE' => 'Por favor, introduzca una fecha válida',
      'ERR_INVALID_HOUR' => 'Por favor, introduzca una hora válida',
      'ERR_INVALID_TIME' => 'Por favor, introduzca un tiempo válido',
      'NTC_CLICK_BACK' => 'Por favor, haga click en el botón "Volver" para corregir el error',
      'LBL_LIST_ASSIGNED_USER' => 'Asignado a',
      'LBL_ASSIGNED_TO' => 'Asignado a',
      'LBL_DATE_MODIFIED' => 'Última modificación:',
      'LBL_DATE_ENTERED' => 'Creado:',
      'LBL_CURRENT_USER_FILTER' => 'Sólo en mis registros:',
      'NTC_LOGIN_MESSAGE' => 'Conectar',
      'LBL_NONE' => '-Ninguno-',
      'LBL_BACK' => 'Volver',
      'LBL_IMPORT' => 'Importar',
      'LBL_EXPORT' => 'Exportar',
      'LBL_EXPORT_ALL' => 'Exportar todas/os las/los',
      'LBL_QUICK_CREATE' => 'Crear ...',
      'Export' => 'Exportar',
      'Import' => 'Importar',
      'Merge' => 'Combinar',
      'ConvertLead' => 'Convertir Pre-Contacto',
      'LBL_SHOW_RESULTS' => 'Mostrar resultados en',
      'LBL_TOTAL_RECORDS_FOUND' => 'Total Registros encontrados:',
      'LBL_SEARCH_RESULTS_FOR' => ' -- Buscar Resultados Para ',
      'LBL_TAG_SEARCH' => ' -- Búsqueda de Etiquetas para ',
      'LBL_NO_DATA' => 'No se encontraron datos',
      'NTC_MERGE_CONFIRMATION' => '¿Está seguro que desea combinar el registro?',
      'LBL_MERGE_BUTTON_TITLE' => 'Combinar',
      'LBL_MERGE_BUTTON_KEY' => 'Combinar',
      'DownloadMergeFile'=>'Descargar documento combinado',
      'LBL_SELECTEMAILTEMPLATE_BUTTON_TITLE' => 'Seleccione Plantilla de Email',
      'LBL_SELECTEMAILTEMPLATE_BUTTON_KEY' => 'Seleccione Plantilla de Email',
      'LBL_SELECTEMAILTEMPLATE_BUTTON_LABEL' => 'Seleccione Plantilla de Email',
      'LBL_MERGE_BUTTON_LABEL' => 'Combinar',
      'LBL_SENDMAIL_BUTTON_TITLE' => 'Enviar Email',
      'LBL_SENDMAIL_BUTTON_KEY' => 'Enviar Email',
      'LBL_SENDMAIL_BUTTON_LABEL' => 'Enviar Email',
      'LBL_UPD_DESC' => 'Descripción',
      'LBL_FILENAME' => 'Nombre de Archivo',
      'LBL_FILE' => 'Archivo',
      'LBL_TYPE' => 'Tipo',
      'LBL_DOWNLOAD' => 'Descargar ahora',
      'LBL_OPERATION' => 'Operación',
      'LBL_GROUP_ALLOCATION_TITLE' => 'Ubicación de mi Grupo ',
      'LBL_ENTITY_NAME' => 'Nombre de la Entidad',
      'LBL_GROUP_NAME' => 'Grupo',
      'LBL_ENTITY_TYPE' => 'Tipo',
      'LBL_NEW_TICKET' => 'Código del Ticket',
      'LBL_TITLE' => 'Título',
      'LBL_PRIORITY' => 'Prioridad',
      'LBL_STATUS' => 'Estado',
      'LBL_CHANGE_OWNER' => 'Modificar Propietario',
      'LBL_CHANGE_STATUS' => 'Modificar Estado',
      'LBL_MASS_DELETE' => 'Eliminar',
      'LBL_ADD_ITEM' => 'Añadir',
      'LBL_ADD_NEW' => 'Añadir',
      'LBL_DEDUCT' => 'Deducido',
      'LBL_CALENDAR_TITLE' => 'Abrir Calendario...',
      'LBL_CALENDAR_ALT' => 'Abrir Calendario...',
      'LBL_CALCULATOR_TITLE' => 'Abrir Calculadora...',
      'LBL_CALCULATOR_ALT' => 'Abrir Calculadora...',
      'LBL_CLOCK_TITLE' => 'Mostrar Reloj...',
      'LBL_CLOCK_ALT' => 'Mostrar Reloj...',
      'LBL_ALL_MENU_TITLE' => 'Abrir Mapa del CRM...',
      'LBL_ALL_MENU_ALT' => 'Abrir Mapa del CRM...',
      'LBL_CHAT_TITLE' => 'Chat...',
      'LBL_CHAT_ALT' => 'Chat...',
      'LBL_SEARCH_TITLE' => 'Buscar en ',
      'LBL_SEARCH_ALT' => 'Buscar en ',
      'LBL_SEARCH_STRING' => 'Buscar...',
      'LBL_SEARCH_FOR' => 'Buscar por',
      'LBL_SEARCH_NOW_BUTTON' => 'Buscar Ahora',
      'LBL_GO_TO' => 'Ir a',
      'LBL_FEWER_BUTTON' => 'Menos',
      'LBL_IN' => 'En',
      'LBL_ADV_SEARCH_MSG_ANY' => 'Coincidir con cualquiera de los siguientes',
      'LBL_ADV_SEARCH_MSG_ALL' => 'Coincidir con todos los siguientes',
      'COMBO_ALL' => 'Todos',
      'LBL_OPEN_ACTIVITIES' => 'Abrir Actividades',
      'LBL_HISTORY' => 'Histórico',
      'LBL_ACTIVITY_HISTORY' => 'Histórico de Eventos',
      'LBL_ATTACHMENTS' => 'Adjuntos',
      'LBL_ATTACHMENT' => 'Adjunto',
      'LBL_TIME' => 'Fecha',
      'LBL_ACTION' => 'Acción',
      'LBL_SUBJECT' => 'Asunto',
      'LBL_RELATED_TO' => 'Relacionado Con',
      'LBL_MULTIPLE' => 'Múltiple',
      'LBL_DUE_DATE' => 'Fecha de Vencimiento',
      'LBL_LAST_MODIFIED' => 'Última Modificación',
      'LBL_CREATED' => 'Creado',
      'LBL_DESCRIPTION' => 'Descripción',
      'LBL_NEW_TASK' => 'Nueva Tarea',
      'LBL_NEW_EVENT' => 'Nuevo Evento',
      'LBL_ATTACHMENT_AND_NOTES' => 'Adjuntos y Notas',
      'LBL_POTENTIAL_NAME' => 'Oportunidad',
      'LBL_CONTACT_NAME' => 'Contacto',
      'LBL_DEPARTMENT' => 'Departamento',
      'LBL_ROLE' => 'Rol',
      'LBL_EMAIL' => 'Email',
      'LBL_PHONE' => 'Teléfono',
      'LBL_PRODUCT' => 'Producto',
      'LBL_AMOUNT' => 'Cantidad',
      'LBL_CLOSE_DATE' => 'Fecha de Cierre',
      'LBL_NEW_ATTACHMENT' => 'Nuevo Adjunto',
      'LBL_PRODUCT_TITLE' => 'Productos',
      'LBL_NEW_PRODUCT' => 'Nuevo Producto',
      'LBL_PRODUCT_NAME' => 'Producto',
      'LBL_QUANTITY' => 'Cantidad',
      'LBL_SALES_PRICE' => 'Precio de Venta',
      'LBL_PURCHASE_DATE' => 'Fecha de Compra',
      'LBL_TICKET_ID' => 'Número de Parte ',
      'LBL_TICKETS' => 'Partes',
      'LBL_POTENTIAL_TITLE' => 'Oportunidades',
      'LBL_NEW_POTENTIAL' => 'Nueva Oportunidad',
      'LBL_LEAD_NAME' => 'Pre-Contacto',
      'LBL_ACCOUNT_NAME' => 'Cuenta',
      'LBL_ACCOUNT_TYPE' => 'Tipo de Cuenta',
      'LBL_USER_TITLE' => 'Usuarios',
      'LBL_CONTACT_TITLE' => 'Contactos',
      'LBL_SHOWING' => 'Mostrando',
      'LBL_SELECT_PRODUCT_BUTTON_LABEL' => 'Seleccionar Producto',
      'LBL_VIEW' => 'Filtros:',
      'LBL_GROUP_VIEW' => 'Grupo',
      'LBL_SALES_STAGE' => 'Fase de Venta',
      'LBL_PROBABILITY' => 'Probabilidad',
      'LBL_BULK_MAILS' => 'E-Mailings',
      'LBL_WORLD_CLOCK' => 'Reloj',
      'LBL_CALCULATOR' => 'Calculadora',
      'LBL_CLOSE_WON' => 'Cerrada-Ganada',
      'LBL_CLOSE_LOST' => 'Cerrada-Perdida',
      'LBL_USER' => 'Usuario',
      'LBL_TEAM' => 'Equipo',
      'LBL_GROUP' => 'Grupo',
      'LBL_NONE_NO_LINE' => 'ninguno',
      'LBL_SELECT_GROUP' => 'Seleccionar un Grupo',
      'LBL_HOUR_AND_MINUTE' => '(horas/minutos)',
      'YEAR_MONTH_DATE' => '24:00',
      'COMBO_LEADS' => 'Pre-Contactos',
      'COMBO_ACCOUNTS' => 'Cuentas',
      'COMBO_CONTACTS' => 'Contactos',
      'COMBO_POTENTIALS' => 'Oportunidades',
      'COMBO_PRODUCTS' => 'Productos',
      'COMBO_HELPDESK' => 'Incidencias',
      'COMBO_USERS' => 'Usuarios',
      'COMBO_CAMPAIGNS' => 'Campañas',
      'LBL_SELECT' => 'Seleccionar',
      'LBL_EDIT' => 'Editar',
      'LBL_DELETE' => 'Eliminar',
      'Name' => 'Nombre',
      'Company' => 'Empresa',
      'Phone' => 'Teléfono',
      'Website' => 'Página Web',
      'Email' => 'Email',
      'Assigned To' => 'Asignado a',
      'Account Name' => 'Cuenta',
      'City' => 'Población',
      'Title' => 'Título',
      'Potential' => 'Oportunidad',
      'Sales Stage' => 'Fase de Venta',
      'Amount' => 'Cantidad',
      'Expected Close' => 'Previsión de Cierre',
      'Subject' => 'Asunto',
      'Contact Name' => 'Contacto',
      'Related to' => 'Relacionado con',
      'File' => 'Archivo',
      'Last Modified' => 'Última Modificación',
      'Close' => 'Cerrar',
      'Type' => 'Tipo',
      'Start Date/Due Date' => 'Fecha de Inicio / Fin',
      'Date Sent' => 'Fecha de Envío',
      'Ticket ID' => 'Código de Parte',
      'Status' => 'Estado',
      'Priority' => 'Prioridad',
      'Product Name' => 'Producto',
      'Commission Rate' => '% Comisión',
      'Quantity In Stock' => 'Cantidad en Stock',
      'Qty/Unit' => 'Cant/Uds',
      'Unit Price' => 'Precio Unitario',
      'Question' => 'Pregunta',
      'Category' => 'Categoría',
      'Price Book Name' => 'Tarifa',
      'LBL_EVENT_ENDDATE' => 'Fecha y Hora de Fin',
      'LBL_CUSTOM_INFORMATION' => 'Información específica',
      'LBL_NONE_SCHEDULED' => 'Ninguna Programada',
      'Leads' => 'Pre-Contactos',
      'Accounts' => 'Cuentas',
      'Accounts & Contacts' => 'Cuentas y Contactos',
      'Contacts' => 'Contactos',
      'Potentials' => 'Oportunidades',
      'Products' => 'Productos',
      'Emails' => 'Emails',
      'HelpDesk' => 'Incidencias',
      'Activities' => 'Tareas',
      'Events' => 'Eventos',
      'Tasks' => 'Tareas',
      'Todo' => 'Tareas Pendientes',
      'Call' => 'Llamada',
      'Meeting' => 'Reunión',
      'PriceBook' => 'Tarifas',
      'Calendar' => 'Calendario',
      'Home' => 'Portada',
      'Campaigns' => 'Campañas',
      'PriceBooks' => 'Tarifas',
      'Faq' => 'Faqs',
      'Dashboards' => 'Indicadores',
      'Reports' => 'Informes',
      'Vendors' => 'Proveedores',
      'Rss' => 'RSS',
      'Portal' => 'Webs Favoritas',
      'Webmails' => 'Webmails',
      'Activity History' => 'Histórico de eventos',
      'Ticket History' => 'Histórico de tickets',
      'Purchase Order' => 'Órdenes de Compra',
      'Sales Stage History' => 'Histórico de ventas',
      'Users' => 'Usuarios',
      'Admin' => 'Admin',
      'PurchaseOrder Status History' => 'Histórico de Órdenes de Compra',
      'SalesOrder Status History' => 'Histórico de Pedidos',
      'Quote Stage History' => 'Histórico de Presupuestos',
      'Invoice Status History' => 'Histórico de Facturas',
      'LBL_TROUBLE_TICKET' => 'Ticket de Problema',
      'My Home Page' => 'Portada',
      'Marketing' => 'Marketing',
      'Sales' => 'Comercial',
      'Support' => 'Atención al Cliente',
      'Analytics' => 'Análisis',
      'Inventory' => 'Inventario',
      'Tools' => 'Herramientas',
      'Settings' => 'Configuración',
      'LBL_INFORMATION' => 'Información',
      'LBL_MORE' => 'Más',
      'LBL_BASIC' => 'Básico',
      'LBL_CREATING' => 'Creando',
      'LBL_DUPLICATING' => 'Duplicando',
      'LBL_EDITING' => 'Editando',
      'LBL_NEW' => 'Nuevo',
      'Lead' => 'Pre-Contacto',
      'Account' => 'Cuenta',
      'Contact' => 'Contacto',
      'Opportunity' => 'Oportunidad',
      'Product' => 'Producto',
      'Activity' => 'Tarea',
      'Event' => 'Evento',
      'Task' => 'Tarea',
      'Quote' => 'Presupuesto',
      'Ticket' => 'Parte',
      'Campaign' => 'Campaña',
      'Dashboard' => 'Indicadores',
      'Report' => 'Informes',
      'Vendor' => 'Proveedor',
      'Webmail' => 'Webmail',
      'LBL_NONE_INCLUDED' => 'Sin Asignar',
      'LBL_ADD_TO' => 'Agregar a',
      'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE' => 'Seleccione una plantilla para enviar el Mailing:',
      'LBL_TITLE_OR_DESCRIPTION' => 'Título/Descripción',
      'LBL_RSS_FEEDS' => 'RSS Feeds',
      'LBL_ADD_RSS_FEEDS' => 'Añadir nuevo Agregador RSS',
      'LNK_NEW_FAQ' => 'Nuevo FAQ',
      'Vendor Name' => 'Nombre del Proveedor',
      'LNK_WEARE' => 'Acerca...',
      'LBL_ABOUTUS_TITLE' => 'vtiger CRM - Sobre Nosotros',
      'LBL_DISCUSS' => 'Comentar con otros usuarios',
      'Quote Stage' => 'Fase del Presupuesto',
      'Potential Name' => 'Oportunidad',
      'Total' => 'Cantidad Total',
      'First Name' => 'Nombre',
      'Last Name' => 'Apellidos',
      'User Name' => 'Usuario',
      'LBL_PORDER_BUTTON_TITLE' => 'Nueva Orden de Compra [Alt+O]',
      'LBL_PORDER_BUTTON' => 'Nueva Orden de Compra',
      'LBL_PORDER_BUTTON_KEY' => 'O',
      'Tracking Number' => 'Nº de parte',
      'Order No' => 'Referencia de la Orden',
      'Quote Name' => 'Referencia del Presupuesto',
      'Invoice No' => 'Nº de Factura',
      'Quote No' => 'Id de Presupuesto',
      'Sales Order' => 'Pedido',
      'COMBO_QUOTES' => 'Presupuestos',
      'End Date' => 'Fecha de Vencimiento',
      'End Date & Time' => 'Fecha y Hora de Vencimiento',
      'Start Date' => 'Fecha de Inicio',
      'Start Date & Time' => 'Fecha y Hora de Inicio',
      'Start Time' => 'Hora Inicio',
      'End Time' => 'Hora Fin',
      'Recurring Type' => 'Periodicidad',
      'SalesOrders' => 'Pedidos',
      'LBL_QUOTE_NAME' => 'Presupuesto',
      'LBL_NEW_QUOTE_BUTTON_TITLE' => 'Nuevo Presupuesto [Alt+Q]',
      'LBL_NEW_QUOTE_BUTTON_KEY' => 'Q',
      'LBL_NEW_QUOTE_BUTTON' => 'Nuevo Presupuesto',
      'COMBO_PORDER' => 'Ordenes de Compra',
      'COMBO_SORDER' => 'Pedidos',
      'LBL_PORDER_NAME' => 'Orden de Compra',
      'LBL_SORDER_NAME' => 'Pedido',
      'COMBO_INVOICES' => 'Facturas',
      'LBL_INVOICE_NAME' => 'Factura',
      'LBL_QUOTES_NAME' => 'Presupuesto',
      'LBL_HELPDESK_NAME' => 'Incidencias',
      'LBL_CAMPAIGN_NAME' => 'Campaña',
      'LBL_NEW_INVOICE_BUTTON_TITLE' => 'Nueva Factura [Alt+I]',
      'LBL_NEW_INVOICE_BUTTON_KEY' => 'I',
      'LBL_NEW_INVOICE_BUTTON' => 'Nueva Factura',
      'LBL_NEW_SORDER_BUTTON_TITLE' => 'Nuevo Pedido [Alt+E]',
      'LBL_NEW_SORDER_BUTTON_KEY' => 'E',
      'LBL_NEW_SORDER_BUTTON' => 'Nuevo Pedido',
      'LBL_PRODUCT_DETAILS' => 'Detalles del Producto',
      'LBL_QTY_IN_STOCK' => 'Cantidad en Stock',
      'LBL_QTY' => 'Cantidad',
      'LBL_UNIT_PRICE' => 'Precio unitario',
      'LBL_LIST_PRICE' => 'Listado de Precios',
      'LBL_TOTAL' => 'Total',
      'LBL_ADD_PRODUCT' => 'Añadir Producto',
      'LBL_SUB_TOTAL' => 'Sub Total',
      'LBL_TAX' => 'Impuesto',
      'LBL_ADJUSTMENT' => 'Descuento',
      'LBL_GRAND_TOTAL' => 'Total',
      'LBL_QUOTE_ID' => 'Importe Total',
      'LBL_SALES_ORDER_ID' => 'Número de Pedido',
      'LBL_PURCHASE_ORDER_ID' => 'Número Orden de Compra',
      'LBL_EXPORT_TO_PDF' => 'Exportar a PDF',
      'LBL_HOME_KEY_METRICS' => 'Estadísticas',
      'LBL_HOME_METRICS' => 'Elemento',
      'LBL_HOME_COUNT' => 'Cantidad',
      'LBL_JSCALENDAR_LANG' => 'es',
      'LNK_CV_EDIT' => 'Editar',
      'LNK_CV_DELETE' => 'Borrar',
      'LNK_CV_CREATEVIEW' => 'Nueva',
      'LBL_UPD_FIELD_ORD' => 'Actualizar el Orden de los Campos',
      'LBL_SEND_CUSTOM_MAIL_BUTTON' => 'Enviar Email Personalizado',
      'LBL_UPDATED_TODAY' => 'Actualizado hoy',
      'LBL_UPDATED' => 'Actualizado hace',
      'LBL_DAY_AGO' => 'día',
      'LBL_DAYS_AGO' => 'días',
      'Jan' => 'Ene',
      'Feb' => 'Feb',
      'Mar' => 'Mar',
      'Apr' => 'Abr',
      'May' => 'May',
      'Jun' => 'Jun',
      'Jul' => 'Jul',
      'Aug' => 'Ago',
      'Sep' => 'Sep',
      'Oct' => 'Oct',
      'Nov' => 'Nov',
      'Dec' => 'Dic',
      'Campaign Name' => 'Nombre de la Campaña',
      'Campaign Type' => 'Tipo de la Campaña',
      'Campaign Status' => 'Estado de Campaña',
      'Expected Revenue' => 'Espectativa de Beneficio',
      'Expected Close Date' => 'Fecha Estimada de Cierre',
      'LBL_ACTIONS' => 'Acciones',
      'LBL_SEND' => 'Enviar',
      'LBL_VAT' => 'IVA',
      'LBL_SALES' => 'Ventas',
      'LBL_SERVICE' => 'Servicio',
      'LBL_TAX_DETAILS' => 'Detalles de Impuestos',
      'LBL_TAX_CALCULATION' => 'Cálculo de Impuestos',
      'LBL_TAX_NAME' => 'Nombre del Impuesto',
      'LBL_TAX_VALUE' => 'Valor de Impuesto',
      'COVERED_PERCENTAGE' => '(%)',
      'LBL_TAG_CLOUD' => 'Nube de Etiquetas',
      'LBL_FOR' => 'para',
      'LBL_PO_STATUS' => 'Estado de Orden de Compra',
      'LBL_SO_STATUS' => 'Estado de Pedido',
      'LBL_INVOICE_STATUS' => 'Estado de Presupuesto',
      'LBL_MODULE' => 'Módulo',
      'Active' => 'Activo',
      'Inactive' => 'Inactivo',
      'Today' => 'Hoy',
      'Last 2 Days' => 'Últimos 2 días',
      'Last Week' => 'Última semana',
      'This Week' => 'Esta semana',
      'This Month' => 'Este mes',
      'This Year' => 'Este año',
      'LBL_PLEASE_CLICK' => 'Haz click',
      'LBL_TO_CONFIGURE' => 'para configurar',
      'LBL_HERE' => 'aquí',
      'LBL_RECORDS' => 'Registros',
      'LBL_SCROLL' => '[Arriba]',
      'LBL_EXPAND_COLLAPSE' => 'Expandir/Contraer',
      'LBL_RCPY_ADDRESS' => 'Copiar Envío a Factura',
      'LBL_LCPY_ADDRESS' => 'Copiar Factura a Envío',
      'LBL_RECORD_ID' => 'ID de Registro',
      'LBL_ACTION_DATE' => 'Fecha de Acción',
      'LBL_HOMEPAGE_DASHBOARD' => 'Indicadores Inicio',
      'LBL_NO' => 'No',
      'LBL_FOUND' => 'Encontrados',
      'LBL_YOU_CAN_CREATE' => 'Crear',
      'LBL_NOW' => 'ahora',
      'LBL_CLICK_THE_LINK' => 'Pulse el enlace inferior',
      'LBL_CREATE' => 'Crear',
      'LBL_A' => 'un',
      'LBL_AN' => 'un',
      'LBL_YOU_ARE_NOT_ALLOWED_TO_CREATE' => 'No está autorizado a crear',
      'LBL_TRANSFER_OWNERSHIP' => 'Transferir Propietario a ',
      'LBL_SELECT_STATUS' => 'Selecione nuevo Estado',
      'LBL_UPDATE_OWNER' => 'Actualizar Propietario',
      'LBL_UPDATE_STATUS' => 'Actualizar Estado',
      'LBL_NET_PRICE' => 'Precio Neto',
      'LBL_TOOLS' => 'Herramientas',
      'LBL_DISCOUNT' => 'Descuentos',
      'LBL_TOTAL_AFTER_DISCOUNT' => 'Total Después de Descuento',
      'LBL_NET_TOTAL' => 'Neto Total',
      'LBL_SHIPPING_AND_HANDLING_CHARGES' => 'Gastos de Manipulación y Transporte',
      'LBL_TAX_FOR_SHIPPING_AND_HANDLING' => 'Impuestos de Manipulación y Transporte',
      'LBL_FINISH' => 'Terminado',
      'LBL_IMAGE_DELETED' => 'Imagen Borrada',
      'LBL_TAX_MODE' => 'Tipo de Impuestos',
      'LBL_CLEAR_COMMENT' => 'Borrar Comentario',
      'LBL_ZERO_DISCOUNT' => 'Sin Descuento',
      'LBL_OF_PRICE' => 'de Precio',
      'LBL_DIRECT_PRICE_REDUCTION' => 'Descuento Directo',
      'LBL_INDIVIDUAL' => 'Individual',
      'LBL_CPY_MAILING_ADDRESS' => 'Copiar Envío a Otra',
      'LBL_CPY_OTHER_ADDRESS' => 'Copiar Otra a Envío',
      'LBL_PERMISSION' => 'No está autorizado a realizar esta operación',
      'VTIGER' => 'Vtiger',
      'LBL_DIRECT_AMOUNT_DISCOUNT' => 'Descuento Directo',
      'LBL_NO_DISCOUNT_FOR_THIS_PRODUCT' => 'Producto sin Descuento',
      'LBL_NO_DISCOUNT_FOR_THIS_LINE_ITEM'=> 'Línea sin Descuento',
      'LBL_TOTAL_TAX_AMOUNT' => 'Total Impuestos',
      'LBL_FINAL_DISCOUNT_AMOUNT' => 'Descuento Final',
      'LBL_SHIPPING_AND_HANDLING_CHARGE' => 'Gastos de Envío',
      'LBL_GO_BACK' => 'Atrás',
      'LBL_RECORD_DELETE' => 'El Registro que pretende ver ha sido borrado.',
      'Part Number' => 'Nº Pieza',
      'Salutation' => 'Saludo ',
      'Rating' => 'Ratio',
      'industry' => 'Industria',
      'Severity' => 'Urgencia',
      'Product Category' => 'Categoría de Producto',
      'GL Account' => 'Cuenta Contable',
      'Usage Unit' => 'Unidad de Uso',
      'Carrier' => 'Transportista',
      'Expected Response' => 'Respuesta Esperada',
      'LBL_ADDRESS_INF' => 'Información de Dirección',
      'yes' => 'yes',
      'no' => 'no',
      'LBL_RENAMEPROFILE_BUTTON_LABEL' => 'Renombrar',
      'LBL_RENAME_PROFILE' => 'Renombrar Perfil',
      'LBL_PROFILE_NAME' => 'Nombre de Perfil',
      'LBL_START_DATE' => 'Fecha de Inicio',
      'LBL_START_DATE_TIME' => 'Fecha y Hora de Inicio',
      'LBL_END_DATE' => 'Fecha de Vencimiento',
      'LBL_END_DATE_TIME' => 'Fecha y Hora de Vencimiento',
      'LBL_CREATE_MERGE_TEMPLATE' => 'Crear plantillas de combinación de correo',
      'LBL_IMG_FORMATS' => '(Sólo imágenes jpg, gif, bmp y png )',
      'group' => 'Grupo',
      'individual' => 'individual',
      'contains' => 'contiene',
      'does_not_contains' => 'no contiene',
      'is' => 'es',
      'is_not' => 'no es',
      'begins_with' => 'empieza con',
      'ends_with' => 'termina con',
      'greater_than' => 'mayor que',
      'less_than' => 'menor que',
      'greater_or_equal' => 'mayor o igual',
      'less_or_equal' => 'menor o igual',
      'LABEL_SET_DISCOUNT_FOR_COLON' => 'Establecer descuento para:',
      'LABEL_SET_TAX_FOR' => 'Establecer Impuesto para',
      'LABEL_SET_DISCOUNT_FOR' => 'Establecer descuento para',
      'LABEL_SET_GROUP_TAX_FOR_COLON' => 'Establecer Impuesto para:',
      'LABEL_SET_DISCOUNT_FOR_X_COLON' => 'Establecer Descuento para x:',
      'LABEL_SET_TAX_FOR_X' => 'Establecer Impuesto para x:',
      'LABEL_SET_SH_TAX_FOR_COLON' => 'Establecer Impuesto de Manipulación y Transportes para:',
      'NO_DATA_AVAILABLE_WITH_SPECIFIED_PERIOD' => 'No hay datos disponible para ese periodo',
      'Files_Maximum_6' => 'Máximo 6 archivos',
      'To' => 'Para:',
      'Date & Time' => 'Fecha y hora:',
      'Reminder' => 'Recordatorio:',
      'Visit_Link' => 'Pulse enlace para más detalles de la actividad',
      'Click here' => 'Pulse aquí',
      'Support_starting' => 'Inicio de Soporte Técnico',
      'Congratulations' => '¡Enhorabuena!, Hoy empieza el Soporte Técnico',
      'Hello_Support' => '¡Hola!, empieza el Soporte Técnico para',
      'Support_Ending_Subject' => 'Fin de Soporte Técnico',
      'Support_Ending_Content' => 'Estimado Administrador,<br /><br />La fecha de soporte del producto <b>',
      'kindly_renew' => '</b> acaba en breve. Recuerde renovar el Soporte Técnico.<br />Saludos<br />El Equipo de Soporte Técnico',
      'Dear_Admin' => 'Estimado Administrador,<br /> Hay demasiados partes pendientes, le rogamos tome las medidas oportunas asignandolos a quien corresponda. <br /> Gracias y Saludos,<br /> El Equipo de Soporte Técnico.',
      'Pending_Tickets' => 'Demasiados Partes pendientes',
      'Pending_Ticket_notification' => 'Notificación de parte pendiente',
      'Kind_Attention' => 'Estimado Administrador,<br /> el parte nº',
      'Thank_You_HelpDesk' => 'debería estar cerrado',
      'Big_Deal_Closed_Successfully' => 'Gran Acuerdo cerrado satisfactoriamente',
      'Dear_Team' => 'Estimado Equipo, <br />',
      'Potential_Name' => 'Nombre:',
      'Potential_Id' => 'Id:',
      'Dear_Team_Time_to_Party' => 'Estimado equipo, hemos cerrado un acuerdo por más de (poner el valor que queráis) €.< br/> Mi más sincera Enhorabuena.',
      'Task_Not_completed' => 'Tarea no Terminada',
      'Too_many_pending_tickets' => 'Demasiados Partes pendientes',
      'Dear_Admin_too_ many_tickets_pending' => 'Estimado Administrador,<br /> Hay demasiados Partes pendientes, le rogamos tome las medidas oportunas asignandolos a quien corresponda. <br /> Gracias y Saludos,<br /> El Equipo de Soporte Técnico.',
      'DELETE_CONFIRMATION' => '¿Está seguro de querer borrar la selección de',
      'SELECT_ATLEAST_ONE' => 'Seleccione, al menos, una entidad',
      'DELETING_ACCOUNT' => 'Al eliminar esta cuenta se eliminarán sus oportunidades, presupuestos, albaranes y facturas asociadas. ¿Estás seguro que quieres eliminar la ',
      'DELETING_VENDOR' => 'Al eliminar este proveedor se eliminarán sus compras asociadas. ¿Estás seguro que quieres eliminar el ',
      'PLEASE_SELECT_MAILID' => 'Selecciones un mail ID',
      'OVERWRITE_EXISTING_ACCOUNT1' => '¿Sobreescribir la dirección existente con la de la cuenta seleccionada (',
      'OVERWRITE_EXISTING_ACCOUNT2' => ')?',
      'MISSING_FIELDS' => 'Faltan Campos Requeridos:',
      'NOT_ALLOWED_TO_EDIT' => 'No tiene autorización para editar este campo',
      'COLUMNS_CANNOT_BE_EMPTY' => 'Las columnas seleccionadas no pueden estar vacías',
      'CANNOT_BE_EMPTY' => 'no pueden estar vacías',
      'CANNOT_BE_NONE' => 'no puede ser ninguna',
      'SERVERNAME_CANNOT_BE_EMPTY' => 'El nombre del Servidor no puede estar vacío',
      'ENTER_VALID' => 'Intoduzca una Id válida',
      'SHOULDBE_LESS' => 'debe ser menor que',
      'SHOULDBE_LESS_EQUAL' => 'debe ser menor o igual a',
      'SHOULDBE_EQUAL' => 'debe ser igual a',
      'SHOULDBE_GREATER' => 'debe ser mayor que',
      'SHOULDBE_GREATER_EQUAL' => 'debe ser mayor o igual a',
      'INVALID' => 'inválido',
      'EXCEEDS_MAX' => 'excede el máximo límite',
      'OUT_OF_RANGE' => 'está fuera de rango',
      'SHOULDNOTBE_EQUAL' => 'no debe ser igual a',
      'PORTAL_PROVIDE_EMAILID' => 'El usuario del portal debe tener un email para conectarse',
      'ADD_CONFIRMATION' => '¿Añadir los seleccionados',
      'ACCOUNTNAME_CANNOT_EMPTY' => 'Nombre de cuenta no puede estar vacio',
      'CANT_SELECT_CONTACTS' => 'No puedes seleccionar contactos relacionados desde oportunidades',
      'LBL_THIS' => 'Este',
      'DOESNOT_HAVE_MAILIDS' => 'no tiene ningún email Id',
      'DOESNOT_HAVE_AN_MAILID' => 'no tiene un email Id',
      'ARE_YOU_SURE' => '¿Está seguro?',
      'MISSING_REPORT_NAME' => 'Falta nombre del informe',
      'REPORT_NAME_EXISTS' => 'El nombre del informe ya existe, use otro.',
      'WANT_TO_CHANGE_CONTACT_ADDR' => '¿Cambiar las direcciones de los contactos relacionados con esta cuenta?',
      'SURE_TO_DELETE' => '¿Borrar?',
      'RECORDS' => 'registros?',
      'NO_PRODUCT_SELECTED' => 'Seleccione al menos un registro',
      'VALID_FINAL_PERCENT' => 'Introduzca un Porcentaje de Descuento válido',
      'VALID_FINAL_AMOUNT' => 'Introduzca un Importe Final válido',
      'VALID_SHIPPING_CHARGE' => 'Introduzca un cargo por Transporte y Manipulado válido',
      'VALID_ADJUSTMENT' => 'Enter un ajuste válido',
      'SELECTED_MORE_THAN_ONCE' => 'Ha seleccionad este producto más de una vez.',
      'WANT_TO_CONTINUE' => '¿Quiere continuar?',
      'ENTER_VALID_TAX' => 'Introduzca un Valor de Impuesto válido',
      'VALID_TAX_NAME' => 'Introduzca un Nombre de Impuesto válido',
      'CORRECT_TAX_VALUE' => 'Introduzca un Valor de Impuesto correcto',
      'ENTER_POSITIVE_VALUE' => 'Introduzca un Valor positivo',
      'LABEL_SHOULDNOT_EMPTY' => 'El nombre del Impuesto no puede estar vacío',
      'NOT_VALID_ENTRY' => 'no es una entrada válida. Introduzca un valor correcto.',
      'VALID_DISCOUNT_PERCENT' => 'Introduzca un Porcentaje de Descuento válido',
      'VALID_DISCOUNT_AMOUNT' => 'Introduzca un Importe de Descuento válido',
      'SELECT_TEMPLATE_TO_MERGE' => 'Seleccione una plantilla para combinar',
      'MISSING_REQUIRED_FIELDS' => 'Faltan Campos Requeridos:',
      'READONLY' => 'Es sólo lectura',
      'SELECT_ATLEAST_ONE_USER' => 'Seleccione al menos un usuario',
      'DISABLE_SHARING_CONFIRMATION' => '¿Desactivar la compartición para los',
      'USERS' => 'usuarios seleccionados?',
      'ENDTIME_GREATER_THAN_STARTTIME' => 'Fecha de fin debe ser anterior a la de inicio',
      'FOLLOWUPTIME_GREATER_THAN_STARTTIME' => '',
      'MISSING_EVENT_NAME' => 'Falta el nombre del evento',
      'EVENT_TYPE_NOT_SELECTED' => 'Seleccione tipo de Evento',
      'OPPORTUNITYNAME_CANNOT_BE_EMPTY' => 'Campo Oportunidad no puede estar vacio',
      'CLOSEDATE_CANNOT_BE_EMPTY' => 'Fecha de Cierre no puede estar vacio',
      'SITEURL_CANNOT_BE_EMPTY' => 'El campo dirección web no puede estar vacío',
      'SITENAME_CANNOT_BE_EMPTY' => 'Nombre del sitio no puede estar vacío',
      'LISTPRICE_CANNOT_BE_EMPTY' => 'La Tarifa no puede estar vacía',
      'INVALID_LIST_PRICE' => 'Tarifa Inválida',
      'PROBLEM_ACCESSSING_URL' => 'Problema al acceder a la dirección web:',
      'CODE' => 'Código:',
      'WISH_TO_QUALIFY_MAIL_AS_CONTACT' => '¿Clasificar el email como contacto?',
      'SELECT_ATLEAST_ONEMSG_TO_DEL' => 'Seleccione al menos un mensaje para borrar',
      'ERROR' => 'Error',
      'FIELD_TYPE_NOT_SELECTED' => 'Campo Tipo no seleccinado',
      'SPECIAL_CHARACTERS_NOT_ALLOWED' => 'No se permiten caracteres especiales en el campo Etiqueta',
      'DUPLICATE_MAPPING_ACCOUNTS' => 'Asignación Duplicada en Cuentas',
      'DUPLICATE_MAPPING_CONTACTS' => 'Asignación Duplicada en Contactos',
      'DUPLICATE_MAPPING_POTENTIAL' => 'Asignación Duplicada en Oportunidades',
      'ERROR_WHILE_EDITING' => 'Error al modificar',
      'PLEASE_ENTER_TAG' => 'Por favor introduzca una etiqueta',
      'PLEASE_SELECT_LINE_ITEM' => 'Por favor seleccione un producto/servicio',
      'DUPLICATE_ENTRIES_FOUND' => 'Seleccione un Producto',
      'ROLE_SHOULDHAVE_INFO' => 'El Rol debe tener al menos un perfil',
      'ENTER_VALID_CONVERSION_RATE' => 'Introduzca un ratio de conversión válido',
      'GROUPNAME_CANNNOT_BE_NONE' => 'Nombre de grupo no puede ser ninguno',
      'GROUP_SHOULDHAVE_ONEMEMBER_INFO' => 'Los Grupos deben tener al menos un miembro. Seleccione un miembro para el grupo.',
      'MAP_DELETED_INFO' => 'Se ha eliminado este mapeo. No se puede volver a utilizar',
      'MUSTHAVE_ONE_REQUIREDFIELD' => 'Debe tener un campo requerido seleccionado.\n',
      'COLUMNS_CANNOT_BE_DUPLICATED' => 'Las columnas no se pueden duplicar',
      'SPECIFY_ROLE_INFO' => 'Especifique un Rol para Transferir los usuarios existentes del Rol',
      'FOLDERNAME_CANNOT_BE_EMPTY' => 'La Carpeta no puede estar vacía',
      'FOLDER_NAME_ALREADY_EXISTS' => 'El Nombre de la carpeta ya existe, use otro.',
      'SELECT_ATLEAST_ONE_REPORT' => 'Seleccione al menos un Informe',
      'DELETE_FOLDER_CONFIRMATION' => '¿Borrar la carpeta \\\'',
      'DELETE_REPORT_CONFIRMATION' => '¿Borrar este informe?',
      'MOVE_REPORT_CONFIRMATION' => '¿Mover el informe a ',
      'FOLDER' => 'carpeta?',
      'ACCOUNT_ACCESS_INFO' => 'Oportunidades, Incidencias, Presupuestos, Pedidos y Facturas deben establecerse como privado cuando Cuentas se establece como privado.',
      'PROFILENAME_CANNOT_BE_EMPTY' => 'El nombre del Perfil no puede estar vacío',
      'PROFILE_DETAILS_UPDATED' => 'Los detalles del perfil se han actualizado',
      'CURRENCY_CHANGE_INFO' => 'Los ',
      'CURRENCY_CONVERSION_INFO' => '¿Está usando el $ como símbolo de Divisa?\n Pulse OK para continuar usando $. Cancelar para cambiar el ratio de conversión',
      'THE_EMAILID' => 'La email Id',
      'EMAIL_FIELD_INVALID' => 'en el campo email es incorrecta',
      'SELECT_VALID_IMAGE' => 'Seleccione una imágen válida',
      'EMAIL_FILED_IS' => 'en el campo email ',
      'OTHER_EMAIL_FILED_IS' => 'en el campo otro email ',
      'SECONDARY_EMAIL_FILED_IS' => 'en el email alternativo ',
      'INVALID_ADD_IN_EMAILFIELD' => ' del campo email no es válido',
      'INVALID_ADD_IN_OTHER_EMAILFIELD' => ' del campo otro email no es válido',
      'ENTER_VALID_4DIGIT_YEAR' => 'Entre un año válido de 4 dígitos entre',
      'AND' => 'y',
      'DATABASE_CHANGE_CONFIRMATION' => '¿Aplicar los cambios de',
      'TO' => 'a',
      'DELETE_RSSFEED_CONFIRMATION' => '¿Borrar RSS?',
      'NOT_PERMITTED_TO_EXPORT' => 'No estás autorizado a exportar',
      'MSG_DEAR' => 'Estimado',
      'MSG_REGARDING' => 'Al respecto',
      'MSG_UPDATION' => 'actualización -',
      'MSG_THE' => 'El',
      'MSG_HAS_BEEN_UPDATED' => 'se ha actualizado',
      'MSG_ASSIGNMENT' => 'asignación - ',
      'MSG_HAS_BEEN_ASSIGNED_TO_YOU' => 'se te ha asignado',
      'MSG_DETAILS_ARE' => 'detalles son',
      'MSG_ID' => 'Id:',
      'MSG_THANK_YOU' => 'Gracias',
      'MSG_HAS_BEEN_CREATED_FOR' => 'se ha creado para',
      'MSG_THANKS' => 'Gracias, ',
      'MSG_VTIGERTEAM' => 'vTiger Team',
      'MSG_IS_NOT_UPLOADED' => 'no se ha subido. Las extensiones permitidas son jpeg, png, jpg, pjpeg, x-png o gif',
      'MSG_IMAGE_ERROR' => 'Imagen no encontrada',
      'Information' => 'Información',
      'Address' => 'Dirección',
      'Custom Information' => 'Información Personalizada',
      'Portal Information' => '- Información del Portal',
      'Description' => 'Descripción',
      'Expectations' => 'Expectativas',
      'Pricing Information' => 'Información de Precios',
      'Stock Information' => 'Información de Stock',
      'Solution' => 'Solución',
      'Terms and Conditions' => 'Condiciones Generales',
      'LBL_SEARCHING' => 'Buscando... Espere',
      'LBL_SKYPE' => 'Skype',
      'LBL_FIND' => 'Buscar',
      'LBL_CLEAR' => 'Borrar',
      'invoice no' => 'nº Factura',
      'LBL_SELECT_LEAD_BUTTON_LABEL' => 'Seleccione Pre-Contacto',
      'LNK_READ_LICENSE' => 'Leer Licencia',
      'ACTIVITIES' => 'Actividades',
      'MAP_NAME_EXISTS' => 'Ya existe una Asignación con este nombre. ¿Sobreescribir?',
      'FOLDER_NAME_ALLOW_20CHARS' => 'El Nombre de la Carpeta admite un máximo de 20 Caracteres',
      'SPECIAL_CHARS_NOT_ALLOWED' => 'No se admiten caracteres especiales',
      'LBL_SIGN_IN' => 'Regístrese',
      'LBL_ROOT' => 'Raiz',
      'LBL_FIRST' => 'Primera',
      'LBL_LAST' => 'Última',
      'LBL_CONTACT_LAST_NAME' => 'Contacto - Apellido',
      'LBL_CONTACT_FIRST_NAME' => 'Contacto - Nombre',
      'Office Phone' => 'Tel. Oficina',
      'Sender' => 'Remitente',
      'Activity Type' => 'Tipo de Actividad',
      'Due Date' => 'Fecha de Vencimiento',
      'Created Time' => 'Fecha de Creación',
      'Modified Time' => 'Fecha de Modificación',
      'FAQ Id' => 'Id FAQ',
      'Lead Status' => 'Estado de Pre-Contacto',
      'Lead Source' => 'Origen de Pre-Contacto',
      'Yahoo Id' => 'Yahoo Id',
      'LBL_CHARSET' => 'UTF-8',
      'Lost Lead' => 'Pre-Contacto Perdido',
      'LBL_SEND_EMAIL_PDF' => 'Enviar Email con PDF',
      'ERR_INVALID_PAGE_COUNT' => 'Paginación Inválida',
      'Quotes' => 'Presupuestos',
      'PurchaseOrder' => 'Órdenes de Compra',
      'SalesOrder' => 'Pedidos',
      'Invoice' => 'Facturas',
      'LBL_CREATING_NEW_Contacts' => 'Creando Nuevo Contacto',
      'LBL_CREATING_NEW_Campaigns' => 'Creando Nueva Campaña',
      'LBL_CREATING_NEW_Leads' => 'Creando Nuevo Pre-Contacto',
      'LBL_CREATING_NEW_Accounts' => 'Creando Nueva Cuenta',
      'LBL_CREATING_NEW_Potentials' => 'Creando Nueva Oportunidad',
      'LBL_CREATING_NEW_Quotes' => 'Creando Nuevo Presupuesto',
      'LBL_CREATING_NEW_SalesOrder' => 'Creando Nuevo Pedido',
      'LBL_CREATING_NEW_Invoice' => 'Creando Nueva Factura',
      'LBL_CREATING_NEW_Products' => 'Creando Nuevo Producto',
      'LBL_CREATING_NEW_PriceBooks' => 'Creando Nueva Tarifa',
      'LBL_CREATING_NEW_HelpDesk' => 'Creando Nueva Incidencia',
      'LBL_CREATING_NEW_Faq' => 'Creando Nueva FAQ',
      'LBL_CREATING_NEW_Vendors' => 'Creando Nuevo Proveedor',
      'LBL_CREATING_NEW_PurchaseOrder' => 'Creando Nuevo Orden de Compra',
      'LBL_UPDATE' => 'Actualizar',
      'LBL_CAL_LIMIT_MSG' => 'Debe indicar un año entre 1970 y 2037',
      'Mobile' => 'Tel. Móvil',
      'Home Phone' => 'Tel. Particular',
      'Other Phone' => 'Tel. Directo',
      'Fax' => 'Fax',
      'Department' => 'Departamento',
      'Birthdate' => 'Cumpleaños',
      'Reports To' => 'Informa a',
      'Assistant' => 'Secretaria',
      'Assistant Phone' => 'Tel. Secretaria',
      'Do Not Call' => 'No Llamar',
      'Email Opt Out' => 'No Enviar Email',
      'Reference' => 'Referencia',
      'Notify Owner' => 'Notificar Gestor',
      'Portal User' => 'Usuario de Portal',
      'Support Start Date' => 'Fecha de Inicio de Soporte',
      'Support End Date' => 'Fecha de Fin de Soporte',
      'Mailing Street' => 'Dirección (Envío)',
      'Other Street' => 'Dirección (Alternativa)',
      'Mailing City' => 'Población (Envío)',
      'Other City' => 'Población(Alternativa)',
      'Mailing State' => 'Provincia (Envío)',
      'Other State' => 'Provincia(Alternativa)',
      'Mailing Zip' => 'Cód. Postal (Envío)',
      'Other Zip' => 'Cód. Postal (Envío)',
      'Mailing Country' => 'País (Envío)',
      'Other Country' => 'País (Alternativa)',
      'Mailing Po Box' => 'Apdo. Postal (Envío)',
      'Other Po Box' => 'Apdo. Postal (Alternativa)',
      'Contact Image' => 'Imagen de Contacto',
      'LBL_EXPORT_TYPE_1' => 'Tipo de Exportación 1:',
      'LBL_EXPORT_TYPE_2' => 'Tipo de Exportación 2:',
      'LBL_SEARCH_CRITERIA_RECORDS' => 'Exportar registros asociados a la búsqueda',
      'LBL_EXPORT_RECORDS' => 'Exportar Tipo de Registro',
      'LBL_WITH_SEARCH' => 'Exportar con Registros de Búsqueda',
      'LBL_WITHOUT_SEARCH' => 'Exportar sin Registros de Búsqueda',
      'LBL_ALL_DATA' => 'Exporta todos los datos',
      'LBL_DATA_IN_CURRENT_PAGE' => 'Exportar dato de la página actual',
      'LBL_ONLY_SELECTED_RECORDS' => 'Export Registros seleccionados',
      'LBL_YES' => 'Si',
      'Planned' => 'Planeada',
      'Held' => 'Mantenida',
      'Not Held' => 'No Mantenida',
      'Completed' => 'Completada',
      'Deferred' => 'Retrasada',
      'Not Started' => 'No Empezada',
      'In Progress' => 'En Progreso',
      'Pending Input' => 'Esperando Datos',
      'Trouble Tickets' => 'Incidencias',
      'LBL_NOT_ACCESSIBLE' => 'No Accesible',
      'Prospecting' => 'Buscando',
      'Qualification' => 'Valorando',
      'Needs Analysis' => 'Necesita Análisis',
      'Value Proposition' => 'Valorando Proposición',
      'Id. Decision Makers' => 'Identificando Responsable',
      'Perception Analysis' => 'Analizando',
      'Proposal/Price Quote' => 'Propuesta/Presupuesto',
      'Negotiation/Review' => 'Negociando/Revisando',
      'Closed Won' => 'Cerrado Ganado',
      'Closed Lost' => 'Cerrado Perdido',
      'NOTE' => 'NOTA',
      'before_migration' => 'antes de iniciar la migración',
      'Set_the_value_of' => 'Establezca el valor de',
      'as' => 'como',
      'ie' => 'por ej.,',
      'add_at_end_of_file' => 'Por favor añada las siguientes líneas al final del archivo config.inc.php.',
      'LBL_MAIL_SEND_STATUS' => 'Estado de Email Enviado:',
      'LBL_MAIL_NOT_SENT_TO_USER' => 'No ha sido posible enviar el correo',
      'LBL_PLS_CHECK_EMAIL_N_SERVER' => 'Compruebe el Email o la configuración del servidor',
      'PLEASE_FILL_QUANTITY' => 'Introduzca la cantidad',
      'LBL_SOLUTION' => 'SOLUCIÓN',
      'LBL_COMMENTS' => 'COMENTARIOS',
      'RELATED' => 'Relacionados',
      'SHOW_ALL' => 'Mostrar todos',
      'RELATED_PARENT' => 'Relacionado con Módulo Superior',
      'LBL_SELECT_PARENTROLE' => 'Seleccione el Rol Superior',
      'LBL_MIGRATION_CHECK' => 'Las versiones del a BD y el archivo son iguales. No puede hacer la migración. Revise la BD y siga los pasos necesarios.',
      'LBL_RECORD_NOT_FOUND' => 'El registro al que pretende acceder no existe',
      'Reorder Level' => 'Nivel de Pedido',
      'Handler' => 'Transportista',
      'Qty In Demand' => 'Cantidad Solicitada',
      'Annual Revenue' => 'Ingresos Anuales',
      'No Of Employees' => 'Nº de Empleados',
      'Employees' => 'Empleados',
      'Probability' => 'Probabilidad',
      'Sales Commission' => 'Comisión de Ventas',
      'Excise Duty' => 'Arancel',
      'Budget Cost' => 'Coste Presupuestado',
      'Actual Cost' => 'Coste Real',
      'Expected Sales Count' => 'Expectativas de Venta',
      'Actual Sales Count' => 'Ventas Reales',
      'Expected Response Count' => 'Respuesta Esperada',
      'Actual Response Count' => 'Respuesta Real',
      'TargetSize' => 'Tamaño Objetivo',
      'Expected ROI' => 'ROI Esperado',
      'Num Sent' => 'Cantidad Enviada',
      'Actual ROI' => 'ROI Real',
      'Ascending' => 'Ascendente',
      'Descending' => 'Descendente',
      'Dear_Admin_tasks_not_been_completed' => 'Estimado Administrador, <br />Hay algunas tareas que no se han terminado 24hrs después de su vencimiento.',
      'Task_sign' => 'Gracias<br>El Equipo de Soporte Técnico<br>',
      //Added for PDF notification
      'LBL_PDF'=>'No se ha podido generar el PDF por superar la anchura máxima permitida, Por favor ',
      //Added for pdf internalization in 5.0.4
      'Thank You'=>'Gracias',
      'For Your Business'=>'Por Su Negocio',
      'Subtotal'=>'Subtotal',
      'Tax'=>'Impuesto',
      'Adjustment'=>'Ajuste',
      'Total'=>'Total',
      'Description'=>'Descripción',
      'Terms & Conditions'=>'Términos y Condiciones',
      'Instructions'=>'Instrucciones',
      'Total Due'=>'Total a Pagar',
      'Detach_Info'=>'Corta por la línea y manda un cheque, orden de domiciliación o resguardo ingreso en el sobre suministrado',
      'Billing Address'=>'Dirección Facturación',
      'Order Number'=>'Número Pedido',
      'Contact Name'=>'Nombre Contacto',
      'Vendor Name'=>'Nombre Proveedor',
      'Due Date'=>'Fecha Pago',
      'Issue Date'=>'Fecha Emisión',
      'Shipping Address'=>'Dirección Envío',
      'Page'=>'Página',
      'Tracking No.'=>'No. Seguimiento',
      'Req. No.'=>'No. Req.',
      'Customer Name'=>'Nombre Cliente',
      'SO Number'=>'Número Pedido',
      'Account Number'=>'Número Cuenta',
      'Valid Till'=>'Válido Hasta',
      'Quote Number'=>'Número Presupuesto',
      'Invoice Number'=>'Número Factura',
      'Product Code'=>'Código Producto',
      'Qty'=>'Ctd',
      'Price'=>'Precio',
      'Discount'=>'Descuento',
      'LBL_ADD_BUTTON' => 'Añadir',
      //PDF VERSION 5.2
      'Net Total' => 'Neto Total',
      'Shipping & Handling Charges' => 'Gastos de Manipulación y Transporte',
      'Shipping & Handling Tax:' => 'Impuestos de Manipulación y Transporte',
      'Quantity'=>'Cantidad',
      'Grand Total : (in €)'=>'Total : (en €)',
      'Issued Date' => 'Fecha',

      // Added after 5.0.4 GA
      
      //Added to Fix i18N issue in Email Template
      'LBL_GENERAL_FIELDS'=>'Campos Generales', 
      //For Users fields
      'HomePhone'=>'Teléfono Casa',
      'Signature'=>'Firma',
      'Street'=>'Calle',
      'State'=>'Estado',
      'Country'=>'País',
      'PostalCode'=>'Código Postal',
      //For General fields
      'Current Date'=>'Fecha Actual',
      'Current Time'=>'Hora Actual',
      
      //Added for Role based Custom filters
      'LBL_PUBLIC'=>'Publico',
      'LBL_PENDING'=>'Pendiente',
      'LBL_OTHERS'=>'Otros',
      
      //For Configuring/Using PurchaseOrder number
      'PO Number'=>'Nº Orden Compra',
      'MSG_AUTO_GEN_ON_SAVE'=>'GEN-AUTO AL GUARDAR',
      
      //For Duplicate merging feature
      'LBL_MERGE' => 'Combinar',
      'LBL_MERGE_BUTTON_TITLE' => 'Combinar',
      'LBL_SAVE_MERGE_BUTTON_TITLE' => 'Encontrar Duplicados',
      'LBL_SELECT_MERGECRITERIA_HEADER' => 'Selección Criterio Combinación',
      'LBL_SELECT_AS_PARENT' => '(selecciona como registro primario)',
      'LBL_SELECT_MERGECRITERIA_TEXT' => 'Selecciona los campos de comparación para encontrar duplicados',
      'LBL_MERGE_SHOULDHAVE_INFO' => 'Selecciona al menos un campo como criterio de combinación',
      'LBL_FIND_DUPLICATES'=>'Encontrar Duplicados',
      'LBL_NO_RECORD'=>'No hay Registros',
      'LBL_NO_DUPLICATE' => 'No hay Registros Duplicados',
      'LBL_LAST_IMPORTED' => 'Ultimos importados',
      'LBL_NOW_IMPORTED'=>'Importados ahora',
      'LBL_EXISTING'=> 'Existentes',
      'LBL_TABLE_CREATED'=>'Tabla Creada Correctamente',
      'LBL_AVAILABLE_FIELDS'=>'Campos Disponibles',
      'LBL_SELECTED_FIELDS'=>' Campos por los que comparar',
      'LBL_MERGE_SELECT'=>'Registros Seleccionados (máx: 3)',
      'DuplicatesHandling' => 'Manejo Duplicados',
      'LBL_DESC_FOR_MERGE_FIELDS' => 'El registro original será guardado después de la combinación. Puedes seleccionar la columna para retener los valores. El otro registro será eliminado pero la información relacionada será combinada.',
      'LBL_DUPLICATE_MERGING' => 'Combinación de Duplicados',
      'LBL_SELECT_TO_ENABLE_MERGING' => 'Selecciona esta opción para habilitar y configurar el criterio de combinación de duplicados',

      // Local Backup Feature
      'LBL_BACKEDUPSUCCESSFULLY_TO_FILE' => 'Copia seguridad a fichero correcta',//BACKUP
      'APP.LBL_NOW'=>'Ahora',//BACKUP
      'LBL_NOW'=>'Ahora',//BACKUP
      
      // Multi-Currency Customization
      'LBL_MORE_CURRENCIES'=>'más monedas',
      'LBL_BASE_CURRENCY'=>'Moneda Base',
      'LBL_CURRENCY'=>'Moneda',
      'LBL_PRICE'=>'Precio',
      'LBL_CONVERSION_RATE'=>'Ratio conversión',
      'LBL_RESET_PRICE'=>'Restaurar Precio',
      'LBL_RESET'=>'Restaurar',
      'LBL_UNIT_PRICE_NOT_PERMITTED'=>'Acceso al Precio Unitario no esta Permitido. No se puede seleccionar productos.',
      
      // Documents module
      'SINGLE_Documents' => 'Documento',
      'LBL_NEW_NOTE' => 'Nuevo Documento',
      'Documents' => 'Documentos',
      'Document' => 'Documento',
      'LBL_NOTE' => 'Documento',
      'LBL_CREATING_NEW_Documents' => 'Creando Nuevo Documento',
      'LBL_PLATFORM_INDEPENDENT'=>'Independiente Plataforma',
      'Attachments' => 'Adjuntos', //added for list header label in related lists
	  'LBL_HIDE'=>'Esconder',

      // Layout Editor and Ease navigation between records in Detail view
      'LNK_LIST_NEXT' => 'Siguiente',
      'LNK_LIST_PREVIOUS' => 'Anterior',
      'LBL_JUMP_BTN'=> 'IR A',
    
      'LBL_ASSIGN_BUTTON_LABEL'=>'Asignar Campos',

      // Mass Edit Feature
      'LBL_MASS_EDIT'=>'Edición Masiva',
      'LBL_MASSEDIT_FORM_HEADER'=>'Edición Masiva - Registros Campos',
    
      // Product Bundles
      'Product Bundles'=>'Productos Compuestos',
    
      // vtlib customization: Language strings
      'VTLIB_MOD_NOT_ACTIVE' => ' módulo no está activado!',
      // END

      // vtiger News & Feedback
     'LBL_VTIGER_NEWS'=>'Noticias vtiger',
     'LBL_FEEDBACK'=>'Cuéntanos',
     // END
     
     //added for asterisk integration
     'CallHistory'=>'Historia de Llamadas',
     'PBXManager'=>'Administrador PBX',
     'LBL_OUTGOING_CALL_MESSAGE'=>'Descuelgue el teléfono para marcar el número',
     'LBL_OUTGOING_CALL'=>'Llamada saliente',
     'LBL_OPERATION_NOT_SUPPORTED'=>'Actualmente no se puede ejecutar esta operación',
     'LBL_ASTERISK_SET_ERROR'=>'No se ha configurado la extensión Asterisk.',
     'LBL_CREATE_LEAD'=>'Crear PreContacto',
     'LBL_CREATE_CONTACT'=>'Crear Contacto',
     'LBL_CREATE_ACCOUNT'=>'Crear Cuenta',
     'LBL_CREATE_TICKET'=>'Crear Incidencia',
     'LBL_INCOMING_CALL'=>'Llamada entrante',
     'LBL_CALLER_INFORMATION'=>'Información Llamada Entrante',
     'LBL_CALLER_NUMBER'=>'Número :',
     'LBL_CALLER_NAME'=>'Nombre :',
     'LBL_INFORMATION_VTIGER'=>'Información de Vtiger',
     //asterisk integration ends

     // Module Sequence Numbering
     'LBL_DUPLICATE' => 'Duplicar',
     'LBL_CLICK' => 'Clic',
     'LBL_TO_CONFIGURE' => 'para Configurar el', 

     // For Privacy Policy
     'LNK_PRIVACY_POLICY'=>'Política de Privacidad',
     'LBL_MOVE_BLOCK_FIELD' => 'Mover Campos',

     //added for find duplicate
     'LBL_DUPLICATE_DATA_IN'=>'Duplicar ',
     'LBL_DELETE'=>'Eliminar',
     'LBL_MERGE_SELECT'=>'Combinar Selección',
     'LBL_MERGE_DATA_IN'=>'Combinar Registro',
     'LBL_MERGE'=>'Combinar',
     'LBL_ACTION'=>'Acción',
     'LBL_FIELDLISTS'=> 'Lista de Campos',
     'LBL_RECORD'=>'Registro #',
     'LBL_DUP_PERMISSION' => 'No tienes permiso para eliminar ',
     'recordid' => 'id registro',
     'Entity Type' => 'Tipo Entidad',

     // gmailbookmarklet customization
     'LBL_GMAIL'=>'Gmail',
     'LBL_BOOKMARKLET'=>'Importar GMail',
     // END

     //ADDED for REPORTS CUSTOMIZING
     'PRIVATE_FILTER'=>'Privado',
     'SHARE_FILTER'=>'Compartido',
     'PUBLIC_FILTER'=>'Publico',

     // Account Hierarchy
     'LBL_ACCOUNT_HIERARCHY' => 'Jerarquía de Cuentas',

     //Prod Bundles
     'LBL_NO_SUB_PRODUCTS'=>'No es un producto compuesto',

     //Custom Fields support for Calendar
     'LBL_ACTIVITY_TYPE'=>'Tipo Actividad',

     // Services model
     'LBL_ADD_SERVICE'=>'Añadir Servicio',
     'LBL_ITEM_DETAILS'=>'Detalles Elemento',
     'LBL_ITEM_NAME'=>'Nombre Elemento',
     'LBL_SETTINGS'=>'Configuración',
     'LAYOUT_EDITOR'=>'Editor Disposición',
     'CUSTOMFIELD_MAPPING'=>'Correspondencia Campo Personalizado',
     'ADD_PORTAL'=>'Añadir a Portal',
     'LBL_FILE_INTEGRITY_CHECK'=>'Comprobar integridad de este fichero',

     //To handle plurals of module names
     'Todos' => 'Tareas',

     // For Popup reminder
     'LBL_POSTPONE'=>'Posponer',

     // Unified Search extended support
     'LBL_SELECT_MODULES_FOR_SEARCH' => 'Selecciona los módulos en los que buscar',
     'LBL_SELECT_ALL' => 'Marcar Todos',
     'LBL_UNSELECT_ALL' => 'Desmarcar Todos',
     'LBL_FIELD_FOR_COMPARISION' => 'Campo a Comparar',
     'LBL_DONE' => ' Hecho ',

     'LBL_NO_MODULES_TO_SELECT' => 'Operación Denegada. No hay Módulos con los que trabajar.',

     'CANNOT_CONVERT' => 'No se puede Convertir',

     // For note link on the detailview
     'LBL_ADD_NOTE'=>'Añadir Nota',

     // For Layout Editor
     'LBL_UNHIDE_FIELDS'=>'Mostrar Campos',

     // For Mass Edit
     'LBL_SELECT_FIELDS_TO_UDPATE_WITH_NEW_VALUE'=>'Selecciona campos a actualizar e introduce su nuevo valor.',

     'LBL_LOADING'=>'Cargando...',
     'LBL_REFRESH' => 'Actualizar',
     'LBL_Reminder' => 'Recordatorio',
     'LBL_RESET_PASSWORD' => 'Reinicializar Contraseña',
     'LBL_PHP_UPGRADE' => 'Has actualizado la versión de php, debido a cambios en el API de la librería crypt tu contraseña ya no es válida, por favor reinicializa tu contraseña.',
     'LBL_RESET_PASSWORD_DESCRIPTION' => 'Puedes reinicializar las contraseñas de todos los usuarios a su nombre de usuario utilizando el programa suministrado.',

     'LBL_CRITERIA_AND'=>'y',
     'LBL_CRITERIA_OR'=>'o',
     'LBL_NEW_GROUP'=>'Nuevo Grupo',
     'LBL_DELETE_GROUP'=>'Eliminar Grupo',
     'LBL_NEW_CONDITION'=>'Nueva Condición',
     'LBL_ADVANCED_FILTER' => 'Búsqueda Avanzada',

     'LBL_CHANGE'=>'Cambiar',
     'LBL_CHANGE_TITLE'=>'Cambiar [Alt+C]',

     'LBL_NEXT_BUTTON_LABEL' => 'Siguiente',

);
$app_list_strings = array (
      'moduleList' => array(
            'Home' => 'Portada',
            'Dashboard' => 'Indicadores',
            'Leads' => 'Pre-Contactos',
            'Contacts' => 'Contactos',
            'Accounts' => 'Cuentas',
            'Potentials' => 'Oportunidades',
            'Campaigns' => 'Campañas',
            'Emails' => 'Emails',
            'Activities' => 'Actividades',
            'Products' => 'Productos',
            'HelpDesk' => 'Incidencias',
            'Faq' => 'Faq',
            'Calendar' => 'Calendario',
            'Quotes' => 'Presupuestos',
            'PurchaseOrder' => 'Órdenes de Compra',
            'Invoice' => 'Facturas',
            'Rss' => 'RSS',
            'Reports' => 'Informes',
            'Vendors' => 'Proveedores',
            'PriceBooks' => 'Tarifas',
            'SalesOrder' => 'Pedidos',
            'Portal' => 'Portal',
            
            // Added after 5.0.4 GA
            'Documents' => 'Documentos',
                             ),
      'opportunity_relationship_type_dom' => array(
            '0' => '',
            'Primary Decision Maker' => 'Toma la Decisión',
            'Business Decision Maker' => 'Decide viabilidad de la propuesta',
            'Business Evaluator' => 'Evalua económicamente la propuesta',
            'Technical Decision Maker' => 'Decide la viabilidad técnica',
            'Technical Evaluator' => 'Evalua técnicamente la propuesta',
            'Executive Sponsor' => 'Pagador',
            'Influencer' => 'Influye',
            'Other' => 'Otra',
                             ),
      'case_relationship_type_dom' => array(
            '0' => '',
            'Primary Contact' => 'Contacto Principal',
            'Alternate Contact' => 'Contacto Alternativo',
                             ),
      'task_priority_dom' => array(
            'High' => 'Alta',
            'Medium' => 'Media',
            'Low' => 'Baja',
                             ),
      'task_status_dom' => array(
            'Planned' => 'Programada',
            'Completed' => 'Finalizada',
            'Deferred' => 'Retrasada',
                             ),
      'meeting_status_dom' => array(
            'Planned' => '',
            'Held' => 'Realizada',
            'Not Held' => 'No Realizada',
                             ),
      'call_status_dom' => array(
            'Planned' => 'Programada',
            'Held' => 'Realizada',
            'Not Held' => 'No Realizada',
                             ),
      'case_status_dom' => array(
            'New' => 'Nuevo',
            'Assigned' => 'Asignado',
            'Closed' => 'Cerrado',
            'Pending Input' => 'Esperando Respuesta',
            'Rejected' => 'Rechazado',
                             ),
      'user_status_dom' => array(
            'Active' => 'Activo',
            'Inactive' => 'Inactivo',
                             ),
      'record_type_display' => array(
            'Accounts' => 'Cuentas',
            'Leads' => 'Pre-Contactos',
            'Opportunities' => 'Oportunidades',
                             ),
);
// Translation for currency names
$app_currency_strings = array(
	'Albania, Leke' 		=> 'Albania, Leke',
	'Argentina, Pesos' 		=> 'Argentina, Pesos',
	'Aruba, Guilders' 		=> 'Aruba, Guilders',
	'Australia, Dollars' 	=> 'Australia, Dollars',
	'Azerbaijan, New Manats'=> 'Azerbaijan, New Manats',
	'Bahamas, Dollars' 		=> 'Bahamas, Dollars',
	'Bahrain, Dinar' 		=> 'Bahrain, Dinar',
	'Barbados, Dollars' 	=> 'Barbados, Dollars',
	'Belarus, Rubles' 		=> 'Belarus, Rubles',
	'Belize, Dollars' 		=> 'Belize, Dollars',
	'Bermuda, Dollars' 		=> 'Bermuda, Dollars',
	'Bolivia, Bolivianos' 	=> 'Bolivia, Bolivianos',
	'Convertible Marka'		=> 'Convertible Marka',
	'Botswana, Pulas' 		=> 'Botswana, Pulas',
	'Bulgaria, Leva' 		=> 'Bulgaria, Leva',
	'Brazil, Reais' 		=> 'Brazil, Reais',
	'Great Britain Pounds' 	=> 'Great Britain Pounds',
	'Brunei Darussalam, Dollars' => 'Brunei Darussalam, Dollars',
	'Canada, Dollars' 		=> 'Canada, Dollars',
	'Cayman Islands, Dollars' => 'Cayman Islands, Dollars',
	'Chile, Pesos' 			=> 'Chile, Pesos',
	'Colombia, Pesos' 		=> 'Colombia, Pesos',
	'Costa Rica, Colón' 	=> 'Costa Rica, Colón',
	'Croatia, Kuna' 		=> 'Croatia, Kuna',
	'Cuba, Pesos' 			=> 'Cuba, Pesos',
	'Cyprus, Pounds'		=> 'Cyprus, Pounds',
	'Czech Republic, Koruny' => 'Czech Republic, Koruny',
	'Denmark, Kroner' 		=> 'Denmark, Kroner',
	'Dominican Republic, Pesos' => 'Dominican Republic, Pesos',
	'East Caribbean, Dollars' => 'East Caribbean, Dollars',
	'Egypt, Pounds' 		=> 'Egypt, Pounds',
	'El Salvador, Colón' 	=> 'El Salvador, Colón',
	'England, Pounds' 		=> 'England, Pounds',
	'Estonia, Krooni' 		=> 'Estonia, Krooni',
	'Euro' 					=> 'Euro',
	'Falkland Islands, Pounds' => 'Falkland Islands, Pounds',
	'Fiji, Dollars' => 'Fiji, Dollars',
	'Ghana, Cedis' 	=> 'Ghana, Cedis',
	'Gibraltar, Pounds' 	=> 'Gibraltar, Pounds',
	'Guatemala, Quetzales' 	=> 'Guatemala, Quetzales',
	'Guernsey, Pounds' 		=> 'Guernsey, Pounds',
	'Guyana, Dollars' 		=> 'Guyana, Dollars',
	'Honduras, Lempiras' 	=> 'Honduras, Lempiras',
	'LvHong Kong, Dollars ' => 'LvHong Kong, Dollars ',
	'Hungary, Forint' 		=> 'Hungary, Forint',
	'Iceland, Krona' 		=> 'Iceland, Krona',
	'India, Rupees' 		=> 'India, Rupees',
	'Indonesia, Rupiahs' 	=> 'Indonesia, Rupiahs',
	'Iran, Rials' 			=> 'Iran, Rials',
	'Isle of Man, Pounds' 	=> 'Isle of Man, Pounds',
	'Israel, New Shekels' 	=> 'Israel, New Shekels',
	'Jamaica, Dollars' 		=> 'Jamaica, Dollars',
	'Japan, Yen' 			=> 'Japan, Yen',
	'Jersey, Pounds' 		=> 'Jersey, Pounds',
	'Kazakhstan, Tenge' 	=> 'Kazakhstan, Tenge',
	'Korea (North), Won' 	=> 'Korea (North), Won',
	'Korea (South), Won' 	=> 'Korea (South), Won',
	'Kyrgyzstan, Soms' 		=> 'Kyrgyzstan, Soms',
	'Laos, Kips' 			=> 'Laos, Kips',
	'Latvia, Lati' 			=> 'Latvia, Lati',
	'Lebanon, Pounds' 		=> 'Lebanon, Pounds',
	'Liberia, Dollars' 		=> 'Liberia, Dollars',
	'Switzerland Francs' 	=> 'Switzerland Francs',
	'Lithuania, Litai' 		=> 'Lithuania, Litai',
	'Macedonia, Denars' 	=> 'Macedonia, Denars',
	'Malaysia, Ringgits' 	=> 'Malaysia, Ringgits',
	'Malta, Liri'			=> 'Malta, Liri',
	'Mauritius, Rupees' 	=> 'Mauritius, Rupees',
	'Mexico, Pesos' 		=> 'Mexico, Pesos',
	'Mongolia, Tugriks' 	=> 'Mongolia, Tugriks',
	'Mozambique, Meticais' 	=> 'Mozambique, Meticais',
	'Namibia, Dollars' 		=> 'Namibia, Dollars',
	'Nepal, Rupees' 		=> 'Nepal, Rupees',
	'Netherlands Antilles, Guilders' => 'Netherlands Antilles, Guilders',
	'New Zealand, Dollars' 	=> 'New Zealand, Dollars',
	'Nicaragua, Cordobas' 	=> 'Nicaragua, Cordobas',
	'Nigeria, Nairas' 		=> 'Nigeria, Nairas',
	'North Korea, Won' 		=> 'North Korea, Won',
	'Norway, Krone' 		=> 'Norway, Krone',
	'Oman, Rials' 			=> 'Oman, Rials',
	'Pakistan, Rupees' 		=> 'Pakistan, Rupees',
	'Panama, Balboa' 		=> 'Panama, Balboa',
	'Paraguay, Guarani' 	=> 'Paraguay, Guarani',
	'Peru, Nuevos Soles' 	=> 'Peru, Nuevos Soles',
	'Philippines, Pesos' 	=> 'Philippines, Pesos',
	'Poland, Zlotych' 		=> 'Poland, Zlotych',
	'Qatar, Rials'			=> 'Qatar, Rials',
	'Romania, New Lei' 		=> 'Romania, New Lei',
	'Russia, Rubles'		=> 'Russia, Rubles',
	'Saint Helena, Pounds' => 'Saint Helena, Pounds',
	'Saudi Arabia, Riyals' => 'Saudi Arabia, Riyals',
	'Serbia, Dinars' 		=> 'Serbia, Dinars',
	'Seychelles, Rupees' 	=> 'Seychelles, Rupees',
	'Singapore, Dollars' 	=> 'Singapore, Dollars',
	'Solomon Islands, Dollars' => 'Solomon Islands, Dollars',
	'Somalia, Shillings' => 'Somalia, Shillings',
	'South Africa, Rand' => 'South Africa, Rand',
	'South Korea, Won' 	=> 'South Korea, Won',
	'Sri Lanka, Rupees' => 'Sri Lanka, Rupees',
	'Sweden, Kronor' 	=> 'Sweden, Kronor',
	'Switzerland, Francs' => 'Switzerland, Francs',
	'Suriname, Dollars' 	=> 'Suriname, Dollars',
	'Syria, Pounds' 		=> 'Syria, Pounds',
	'Taiwan, New Dollars' 	=> 'Taiwan, New Dollars',
	'Thailand, Baht' 		=> 'Thailand, Baht',
	'Trinidad and Tobago, Dollars' => 'Trinidad and Tobago, Dollars',
	'Turkey, New Lira' 		=> 'Turkey, New Lira',
	'Turkey, Liras' 		=> 'Turkey, Liras',
	'Tuvalu, Dollars' 		=> 'Tuvalu, Dollars',
	'Ukraine, Hryvnia' 		=> 'Ukraine, Hryvnia',
	'United Kingdom, Pounds' => 'United Kingdom, Pounds',
	'USA, Dollars' 			=> 'USA, Dollars',
	'Uruguay, Pesos' 		=> 'Uruguay, Pesos',
	'Uzbekistan, Sums' 		=> 'Uzbekistan, Sums',
	'Venezuela, Bolivares Fuertes' => 'Venezuela, Bolivares Fuertes',
	'Vietnam, Dong' 		=> 'Vietnam, Dong',
	'Zimbabwe Dollars' 		=> 'Zimbabwe Dollars',
	'China, Yuan Renminbi' 	=> 'China, Yuan Renminbi',
	'Afghanistan, Afghanis' => 'Afghanistan, Afghanis',
	'Cambodia, Riels' 		=> 'Cambodia, Riels',
    'China, Yuan Renminbi' => 'China, Yuan Renminbi',
    'Jordan, Dinar' => 'Jordan, Dinar',
    'Kenya, Shilling' => 'Kenya, Shilling',
    'MADAGASCAR, Malagasy Ariary' => 'MADAGASCAR, Malagasy Ariary',
    'United Arab Emirates, Dirham' => 'United Arab Emirates, Dirham',
    'United Republic of Tanzania, Shilling' => 'United Republic of Tanzania, Shilling',
    'Yemen, Rials'			=> 'Yemen, Rials',
    'Zambia, Kwacha' => 'Zambia, Kwacha',
	'Malawi, kwacha'		=> 'Malawi, kwacha',
	'Tunisian, Dinar'		=> 'Tunisian, Dinar',
	'Moroccan, Dirham'		=> 'Moroccan, Dirham',
);
?>
